@@ -2,8 +2,9 @@
 #'
 #' Interpretation of indices of fit found in confirmatory analysis or structural equation modelling, such as RMSEA, CFI, NFI, IFI, etc.
 #'
-#' @param x vector of values.
+#' @param x vector of values, or an object of class `lavaan`.
 #' @param rules Can be `"default"` or custom set of [rules()].
+#' @inheritParams interpret
 #'
 #' @inherit performance::model_performance.lavaan details
 #' @inherit performance::model_performance.lavaan references
@@ -41,6 +42,14 @@
 #' interpret_ifi(c(.5, .99))
 #' interpret_pnfi(c(.5, .99))
 #'
+#' # Structural Equation Models (SEM)
+#' if (require("lavaan")) {
+#'   structure <- " ind60 =~ x1 + x2 + x3
+#'                  dem60 =~ y1 + y2 + y3
+#'                  dem60 ~ ind60 "
+#'   model <- lavaan::sem(structure, data = PoliticalDemocracy)
+#'   # interpret(model)  # Not working until new performance is up
+#' }
 #' @references
 #' - Awang, Z. (2012). A handbook on SEM. Structural equation modeling.
 #' - Byrne, B. M. (1994). Structural equation modeling with EQS and EQS/Windows. Thousand Oaks, CA: Sage Publications.
@@ -54,7 +63,7 @@ interpret_gfi <- function(x, rules = "default") {
   rules <- .match.rules(
     rules,
     list(
-      default = rules(c(0.95), c("poor", "satisfactory"), name = "default")
+      default = rules(c(0.95), c("poor", "satisfactory"), name = "default", right = FALSE)
     )
   )
 
@@ -68,7 +77,7 @@ interpret_agfi <- function(x, rules = "default") {
   rules <- .match.rules(
     rules,
     list(
-      default = rules(c(0.90), c("poor", "satisfactory"), name = "default")
+      default = rules(c(0.90), c("poor", "satisfactory"), name = "default", right = FALSE)
     )
   )
 
@@ -82,8 +91,8 @@ interpret_nfi <- function(x, rules = "byrne1994") {
   rules <- .match.rules(
     rules,
     list(
-      byrne1994 = rules(c(0.90), c("poor", "satisfactory"), name = "byrne1994"),
-      schumacker2004 =  rules(c(0.95), c("poor", "satisfactory"), name = "schumacker2004")
+      byrne1994 = rules(c(0.90), c("poor", "satisfactory"), name = "byrne1994", right = FALSE),
+      schumacker2004 = rules(c(0.95), c("poor", "satisfactory"), name = "schumacker2004", right = FALSE)
     )
   )
 
@@ -101,7 +110,7 @@ interpret_cfi <- function(x, rules = "default") {
   rules <- .match.rules(
     rules,
     list(
-      default = rules(c(0.90), c("poor", "satisfactory"), name = "default")
+      default = rules(c(0.90), c("poor", "satisfactory"), name = "default", right = FALSE)
     )
   )
 
@@ -145,7 +154,7 @@ interpret_rfi <- function(x, rules = "default") {
   rules <- .match.rules(
     rules,
     list(
-      default = rules(c(0.90), c("poor", "satisfactory"), name = "default")
+      default = rules(c(0.90), c("poor", "satisfactory"), name = "default", right = FALSE)
     )
   )
 
@@ -158,7 +167,7 @@ interpret_ifi <- function(x, rules = "default") {
   rules <- .match.rules(
     rules,
     list(
-      default = rules(c(0.90), c("poor", "satisfactory"), name = "default")
+      default = rules(c(0.90), c("poor", "satisfactory"), name = "default", right = FALSE)
     )
   )
 
@@ -177,3 +186,150 @@ interpret_pnfi <- function(x, rules = "default") {
 
   interpret(x, rules)
 }
+
+
+# lavaan ------------------------------------------------------------------
+
+#' @rdname interpret_gfi
+#' @export
+interpret.lavaan <- function(x, ...) {
+  interpret(performance::model_performance(x, ...), ...)
+}
+
+#' @rdname interpret_gfi
+#' @export
+interpret.performance_lavaan <- function(x, ...) {
+  table <- data.frame(Name = c(), Value = c(), Interpretation = c(), Threshold = c())
+
+  # GFI
+  if ("GFI" %in% names(x)) {
+    table <- rbind(
+      table,
+      data.frame(
+        Name = "GFI",
+        Value = x$GFI,
+        Interpretation = interpret_gfi(x$GFI),
+        Threshold = 0.95
+      )
+    )
+  }
+
+  # AGFI
+  if ("AGFI" %in% names(x)) {
+    table <- rbind(
+      table,
+      data.frame(
+        Name = "AGFI",
+        Value = x$AGFI,
+        Interpretation = interpret_agfi(x$AGFI),
+        Threshold = 0.90
+      )
+    )
+  }
+
+  # NFI
+  if ("NFI" %in% names(x)) {
+    table <- rbind(
+      table,
+      data.frame(
+        Name = "NFI",
+        Value = x$NFI,
+        Interpretation = interpret_nfi(x$NFI, rules = "byrne1994"),
+        Threshold = 0.90
+      )
+    )
+  }
+
+  # NNFI
+  if ("NNFI" %in% names(x)) {
+    table <- rbind(
+      table,
+      data.frame(
+        Name = "NNFI",
+        Value = x$NNFI,
+        Interpretation = interpret_nnfi(x$NNFI, rules = "byrne1994"),
+        Threshold = 0.90
+      )
+    )
+  }
+
+  # CFI
+  if ("CFI" %in% names(x)) {
+    table <- rbind(
+      table,
+      data.frame(
+        Name = "CFI",
+        Value = x$CFI,
+        Interpretation = interpret_cfi(x$CFI),
+        Threshold = 0.90
+      )
+    )
+  }
+
+  # RMSEA
+  if ("RMSEA" %in% names(x)) {
+    table <- rbind(
+      table,
+      data.frame(
+        Name = "RMSEA",
+        Value = x$RMSEA,
+        Interpretation = interpret_rmsea(x$RMSEA),
+        Threshold = 0.05
+      )
+    )
+  }
+
+  # SRMR
+  if ("SRMR" %in% names(x)) {
+    table <- rbind(
+      table,
+      data.frame(
+        Name = "SRMR",
+        Value = x$SRMR,
+        Interpretation = interpret_srmr(x$SRMR),
+        Threshold = 0.08
+      )
+    )
+  }
+
+  # RFI
+  if ("RFI" %in% names(x)) {
+    table <- rbind(
+      table,
+      data.frame(
+        Name = "RFI",
+        Value = x$RFI,
+        Interpretation = interpret_rfi(x$RFI),
+        Threshold = 0.90
+      )
+    )
+  }
+
+  # IFI
+  if ("IFI" %in% names(x)) {
+    table <- rbind(
+      table,
+      data.frame(
+        Name = "IFI",
+        Value = x$IFI,
+        Interpretation = interpret_ifi(x$IFI),
+        Threshold = 0.90
+      )
+    )
+  }
+
+  # IFI
+  if ("PNFI" %in% names(x)) {
+    table <- rbind(
+      table,
+      data.frame(
+        Name = "PNFI",
+        Value = x$PNFI,
+        Interpretation = interpret_pnfi(x$PNFI),
+        Threshold = 0.50
+      )
+    )
+  }
+
+  table
+}
