@@ -11,7 +11,6 @@
 #' @examples
 #' model <- lm(Sepal.Length ~ Species * Petal.Width, data = iris)
 #' interpret_parameters(model)
-#'
 #' @export
 interpret_parameters <- function(model, ...) {
   ## ----------------------------- NOTE ---------------------------------------
@@ -20,8 +19,9 @@ interpret_parameters <- function(model, ...) {
   ## SLOPES.
   ## --------------------------------------------------------------------------
   warning("This function is highly experimental!\n",
-          "See discussion at github.com/easystats/effectsize/issues/127",
-          call. = FALSE)
+    "See discussion at github.com/easystats/effectsize/issues/127",
+    call. = FALSE
+  )
   UseMethod("interpret_parameters")
 }
 
